# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2019-05-30 20:21:14 UTC
from __future__ import unicode_literals
import datetime

version = "3.2"
githash = "20deaeb79b0518fa9bb9dbcd46f1baed79b6f736"


major = 3
minor = 2
bugfix = 0

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 5, 30, 20, 21, 14)
debug = False

astropy_helpers_version = ""
