# Autogenerated by Astropy's setup.py on 2019-05-30 20:21:15 UTC
from __future__ import unicode_literals
import datetime

version = "3.2rc2"
githash = "db1336313c3a7cca12184beb7224e4e93db3133a"


major = 3
minor = 2
bugfix = 0

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 5, 30, 20, 21, 15)
debug = False

astropy_helpers_version = "3.2"
